summaryrefslogtreecommitdiff
path: root/libavformat
diff options
context:
space:
mode:
Diffstat (limited to 'libavformat')
-rw-r--r--libavformat/dc1394.c2
-rw-r--r--libavformat/grab.c4
-rw-r--r--libavformat/sgi.c12
-rw-r--r--libavformat/v4l2.c4
-rw-r--r--libavformat/x11grab.c2
5 files changed, 12 insertions, 12 deletions
diff --git a/libavformat/dc1394.c b/libavformat/dc1394.c
index 5098c0fdfc..70bbf2e75a 100644
--- a/libavformat/dc1394.c
+++ b/libavformat/dc1394.c
@@ -42,7 +42,7 @@ struct dc1394_frame_format {
int frame_size_id;
} dc1394_frame_formats[] = {
{ 320, 240, PIX_FMT_UYVY422, MODE_320x240_YUV422 },
- { 640, 480, PIX_FMT_UYVY411, MODE_640x480_YUV411 },
+ { 640, 480, PIX_FMT_UYYVYY411, MODE_640x480_YUV411 },
{ 640, 480, PIX_FMT_UYVY422, MODE_640x480_YUV422 },
{ 0, 0, 0, MODE_320x240_YUV422 } /* default -- gotta be the last one */
};
diff --git a/libavformat/grab.c b/libavformat/grab.c
index 4f37b87fad..4395c18846 100644
--- a/libavformat/grab.c
+++ b/libavformat/grab.c
@@ -124,7 +124,7 @@ static int grab_read_header(AVFormatContext *s1, AVFormatParameters *ap)
if (ap->pix_fmt == PIX_FMT_YUV420P) {
desired_palette = VIDEO_PALETTE_YUV420P;
desired_depth = 12;
- } else if (ap->pix_fmt == PIX_FMT_YUV422) {
+ } else if (ap->pix_fmt == PIX_FMT_YUYV422) {
desired_palette = VIDEO_PALETTE_YUV422;
desired_depth = 16;
} else if (ap->pix_fmt == PIX_FMT_BGR24) {
@@ -260,7 +260,7 @@ static int grab_read_header(AVFormatContext *s1, AVFormatParameters *ap)
break;
case VIDEO_PALETTE_YUV422:
frame_size = width * height * 2;
- st->codec->pix_fmt = PIX_FMT_YUV422;
+ st->codec->pix_fmt = PIX_FMT_YUYV422;
break;
case VIDEO_PALETTE_RGB24:
frame_size = width * height * 3;
diff --git a/libavformat/v4l2.c b/libavformat/v4l2.c
index d6384e1e05..d5754aef49 100644
--- a/libavformat/v4l2.c
+++ b/libavformat/v4l2.c
@@ -74,7 +74,7 @@ static struct fmt_map fmt_conversion_table[] = {
.v4l2_fmt = V4L2_PIX_FMT_YUV422P,
},
{
- .ff_fmt = PIX_FMT_YUV422,
+ .ff_fmt = PIX_FMT_YUYV422,
.v4l2_fmt = V4L2_PIX_FMT_YUYV,
},
{
@@ -99,7 +99,7 @@ static struct fmt_map fmt_conversion_table[] = {
},
/*
{
- .ff_fmt = PIX_FMT_RGBA32,
+ .ff_fmt = PIX_FMT_RGB32,
.v4l2_fmt = V4L2_PIX_FMT_BGR32,
},
*/
diff --git a/libavformat/x11grab.c b/libavformat/x11grab.c
index 86b13ed548..f3e5579fb8 100644
--- a/libavformat/x11grab.c
+++ b/libavformat/x11grab.c
@@ -221,7 +221,7 @@ x11grab_read_header(AVFormatContext *s1, AVFormatParameters *ap)
return AVERROR_IO;
}
#endif
- input_pixfmt = PIX_FMT_RGBA32;
+ input_pixfmt = PIX_FMT_RGB32;
break;
default:
av_log(s1, AV_LOG_ERROR, "image depth %i not supported ... aborting\n", image->bits_per_pixel);
diff --git a/libavformat/sgi.c b/libavformat/sgi.c
index 5adcb3791e..da6501b61e 100644
--- a/libavformat/sgi.c
+++ b/libavformat/sgi.c
@@ -101,7 +101,7 @@ static int read_uncompressed_sgi(const SGIInfo *si,
for (z = 0; z < si->zsize; z++) {
#ifndef WORDS_BIGENDIAN
/* rgba -> bgra for rgba32 on little endian cpus */
if (si->zsize == 4 && z != 3)
chan_offset = 2 - z;
else
@@ -130,7 +130,7 @@ static int expand_rle_row(ByteIOContext *f, unsigned char *optr,
int length = 0;
#ifndef WORDS_BIGENDIAN
/* rgba -> bgra for rgba32 on little endian cpus */
if (pixelstride == 4 && chan_offset != 3) {
chan_offset = 2 - chan_offset;
}
@@ -241,7 +241,7 @@ static int sgi_read(ByteIOContext *f,
} else if (s->zsize == SGI_RGB) {
info->pix_fmt = PIX_FMT_RGB24;
} else if (s->zsize == SGI_RGBA) {
- info->pix_fmt = PIX_FMT_RGBA32;
+ info->pix_fmt = PIX_FMT_RGB32;
} else {
return AVERROR_INVALIDDATA;
}
@@ -386,7 +386,7 @@ static int sgi_write(ByteIOContext *pb, AVImageInfo *info)
si->dimension = SGI_MULTI_CHAN;
si->zsize = SGI_RGB;
break;
- case PIX_FMT_RGBA32:
+ case PIX_FMT_RGB32:
si->dimension = SGI_MULTI_CHAN;
si->zsize = SGI_RGBA;
break;
@@ -408,7 +408,7 @@ static int sgi_write(ByteIOContext *pb, AVImageInfo *info)
for (z = 0; z < si->zsize; z++) {
#ifndef WORDS_BIGENDIAN
/* rgba -> bgra for rgba32 on little endian cpus */
if (si->zsize == 4 && z != 3)
chan_offset = 2 - z;
else
@@ -451,7 +451,7 @@ AVImageFormat sgi_image_format = {
"sgi,rgb,rgba,bw",
sgi_probe,
sgi_read,
- (1 << PIX_FMT_GRAY8) | (1 << PIX_FMT_RGB24) | (1 << PIX_FMT_RGBA32),
+ (1 << PIX_FMT_GRAY8) | (1 << PIX_FMT_RGB24) | (1 << PIX_FMT_RGB32),
#ifdef CONFIG_MUXERS
sgi_write,
#else
@@ -101,7 +101,7 @@ static int read_uncompressed_sgi(const SGIInfo *si,
for (z = 0; z < si->zsize; z++) {
#ifndef WORDS_BIGENDIAN
- /* rgba -> bgra for rgba32 on little endian cpus */
+ /* rgba -> bgra for rgb32 on little endian cpus */
if (si->zsize == 4 && z != 3)
chan_offset = 2 - z;
@@ -130,7 +130,7 @@ static int expand_rle_row(ByteIOContext *f, unsigned char *optr,
int length = 0;
#ifndef WORDS_BIGENDIAN
- /* rgba -> bgra for rgba32 on little endian cpus */
+ /* rgba -> bgra for rgb32 on little endian cpus */
if (pixelstride == 4 && chan_offset != 3) {
chan_offset = 2 - chan_offset;
@@ -408,7 +408,7 @@ static int sgi_write(ByteIOContext *pb, AVImageInfo *info)
for (z = 0; z < si->zsize; z++) {
#ifndef WORDS_BIGENDIAN
- /* rgba -> bgra for rgba32 on little endian cpus */
+ /* rgba -> bgra for rgb32 on little endian cpus */
if (si->zsize == 4 && z != 3)
chan_offset = 2 - z;